Struct querylizer::Form
source · [−]pub struct Form<'s, F> where
F: for<'a> EncodingFn<'a>, { /* private fields */ }Expand description
Serialize a value into an OpenAPI form query parameter.
Implementations
sourceimpl<'s, F> Form<'s, F> where
F: for<'a> EncodingFn<'a>,
impl<'s, F> Form<'s, F> where
F: for<'a> EncodingFn<'a>,
sourcepub fn to_string<T>(
name: &str,
value: &T,
explode: bool,
encoder: F
) -> Result<String, QuerylizerError> where
T: Serialize,
pub fn to_string<T>(
name: &str,
value: &T,
explode: bool,
encoder: F
) -> Result<String, QuerylizerError> where
T: Serialize,
Serialize a form value into a new string to be used for web requests.
If explode is false:
- sequences and tuples use the name once and items are comma-separated (
name=item1,item2) - maps and structs use the name once and keys and values are comma separated
(
name=key1,value1,key2,value2).
If explode is true:
- sequences repeat the name and separate with
&(name=item1&name=item2) - maps and structs do not use the name and keys and values are separated with
=(key1=value1&key2=value2)
Example
use querylizer::{encode_query, Form};
#[derive(serde::Serialize)]
struct A {
a: i32,
b: String,
}
let a = A { a: 12, b: "#hello".to_owned() };
let s = Form::to_string("value", &a, false, encode_query).unwrap();
assert_eq!(s, "value=a,12,b,%23hello".to_owned());sourcepub fn extend<T>(
output: &mut String,
name: &str,
value: &T,
explode: bool,
encoder: F
) -> Result<(), QuerylizerError> where
T: Serialize,
pub fn extend<T>(
output: &mut String,
name: &str,
value: &T,
explode: bool,
encoder: F
) -> Result<(), QuerylizerError> where
T: Serialize,
Append a form value onto an existing string to be used for web requests.
If explode is false:
- sequences and tuples use the name once and items are comma-separated (
name=item1,item2) - maps and structs use the name once and keys and values are comma separated
(
name=key1,value1,key2,value2).
If explode is true:
- sequences repeat the name and separate with
&(name=item1&name=item2) - maps and structs do not use the name and keys and values are separated with
=(key1=value1&key2=value2)
Example
use querylizer::{encode_query, Form};
#[derive(serde::Serialize)]
struct A {
a: i32,
b: String,
}
let a = A { a: 12, b: "#hello".to_owned() };
let mut s = "https://example.com/v1/?".to_owned();
Form::extend(&mut s, "value", &a, true, encode_query).unwrap();
assert_eq!(s, "https://example.com/v1/?a=12&b=%23hello".to_owned());Trait Implementations
sourceimpl<'a, 's, F> SerializeMap for &'a mut Form<'s, F> where
F: for<'b> EncodingFn<'b>,
impl<'a, 's, F> SerializeMap for &'a mut Form<'s, F> where
F: for<'b> EncodingFn<'b>,
type Error = QuerylizerError
type Error = QuerylizerError
Must match the Error type of our Serializer.
sourcefn serialize_key<T: ?Sized>(&mut self, key: &T) -> Result<(), Self::Error> where
T: Serialize,
fn serialize_key<T: ?Sized>(&mut self, key: &T) -> Result<(), Self::Error> where
T: Serialize,
Serialize a map key. Read more
sourceimpl<'a, 's, F> SerializeSeq for &'a mut Form<'s, F> where
F: for<'b> EncodingFn<'b>,
impl<'a, 's, F> SerializeSeq for &'a mut Form<'s, F> where
F: for<'b> EncodingFn<'b>,
type Error = QuerylizerError
type Error = QuerylizerError
Must match the Error type of our Serializer.
sourceimpl<'a, 's, F> SerializeStruct for &'a mut Form<'s, F> where
F: for<'b> EncodingFn<'b>,
impl<'a, 's, F> SerializeStruct for &'a mut Form<'s, F> where
F: for<'b> EncodingFn<'b>,
sourceimpl<'a, 's, F> SerializeStructVariant for &'a mut Form<'s, F> where
F: for<'b> EncodingFn<'b>,
impl<'a, 's, F> SerializeStructVariant for &'a mut Form<'s, F> where
F: for<'b> EncodingFn<'b>,
sourceimpl<'a, 's, F> SerializeTuple for &'a mut Form<'s, F> where
F: for<'b> EncodingFn<'b>,
impl<'a, 's, F> SerializeTuple for &'a mut Form<'s, F> where
F: for<'b> EncodingFn<'b>,
type Error = QuerylizerError
type Error = QuerylizerError
Must match the Error type of our Serializer.
sourceimpl<'a, 's, F> SerializeTupleStruct for &'a mut Form<'s, F> where
F: for<'b> EncodingFn<'b>,
impl<'a, 's, F> SerializeTupleStruct for &'a mut Form<'s, F> where
F: for<'b> EncodingFn<'b>,
type Error = QuerylizerError
type Error = QuerylizerError
Must match the Error type of our Serializer.
sourceimpl<'a, 's, F> SerializeTupleVariant for &'a mut Form<'s, F> where
F: for<'b> EncodingFn<'b>,
impl<'a, 's, F> SerializeTupleVariant for &'a mut Form<'s, F> where
F: for<'b> EncodingFn<'b>,
type Error = QuerylizerError
type Error = QuerylizerError
Must match the Error type of our Serializer.
sourceimpl<'a, 's, F> Serializer for &'a mut Form<'s, F> where
F: for<'b> EncodingFn<'b>,
impl<'a, 's, F> Serializer for &'a mut Form<'s, F> where
F: for<'b> EncodingFn<'b>,
type Ok = ()
type Ok = ()
The output type produced by this Serializer during successful
serialization. Most serializers that produce text or binary output
should set Ok = () and serialize into an io::Write or buffer
contained within the Serializer instance. Serializers that build
in-memory data structures may be simplified by using Ok to propagate
the data structure around. Read more
type Error = QuerylizerError
type Error = QuerylizerError
The error type when some error occurs during serialization.
type SerializeSeq = Self
type SerializeSeq = Self
Type returned from serialize_seq for serializing the content of the
sequence. Read more
type SerializeTuple = Self
type SerializeTuple = Self
Type returned from serialize_tuple for serializing the content of
the tuple. Read more
type SerializeTupleStruct = Self
type SerializeTupleStruct = Self
Type returned from serialize_tuple_struct for serializing the
content of the tuple struct. Read more
type SerializeTupleVariant = Self
type SerializeTupleVariant = Self
Type returned from serialize_tuple_variant for serializing the
content of the tuple variant. Read more
type SerializeMap = Self
type SerializeMap = Self
Type returned from serialize_map for serializing the content of the
map. Read more
type SerializeStruct = Self
type SerializeStruct = Self
Type returned from serialize_struct for serializing the content of
the struct. Read more
type SerializeStructVariant = Self
type SerializeStructVariant = Self
Type returned from serialize_struct_variant for serializing the
content of the struct variant. Read more
sourcefn serialize_bool(self, _v: bool) -> Result<Self::Ok, Self::Error>
fn serialize_bool(self, _v: bool) -> Result<Self::Ok, Self::Error>
Serialize a bool value. Read more
sourcefn serialize_i16(self, v: i16) -> Result<Self::Ok, Self::Error>
fn serialize_i16(self, v: i16) -> Result<Self::Ok, Self::Error>
Serialize an i16 value. Read more
sourcefn serialize_i32(self, v: i32) -> Result<Self::Ok, Self::Error>
fn serialize_i32(self, v: i32) -> Result<Self::Ok, Self::Error>
Serialize an i32 value. Read more
sourcefn serialize_i64(self, v: i64) -> Result<Self::Ok, Self::Error>
fn serialize_i64(self, v: i64) -> Result<Self::Ok, Self::Error>
Serialize an i64 value. Read more
sourcefn serialize_i128(self, v: i128) -> Result<Self::Ok, Self::Error>
fn serialize_i128(self, v: i128) -> Result<Self::Ok, Self::Error>
Serialize an i128 value. Read more
sourcefn serialize_u16(self, v: u16) -> Result<Self::Ok, Self::Error>
fn serialize_u16(self, v: u16) -> Result<Self::Ok, Self::Error>
Serialize a u16 value. Read more
sourcefn serialize_u32(self, v: u32) -> Result<Self::Ok, Self::Error>
fn serialize_u32(self, v: u32) -> Result<Self::Ok, Self::Error>
Serialize a u32 value. Read more
sourcefn serialize_u64(self, v: u64) -> Result<Self::Ok, Self::Error>
fn serialize_u64(self, v: u64) -> Result<Self::Ok, Self::Error>
Serialize a u64 value. Read more
sourcefn serialize_u128(self, v: u128) -> Result<Self::Ok, Self::Error>
fn serialize_u128(self, v: u128) -> Result<Self::Ok, Self::Error>
Serialize a u128 value. Read more
sourcefn serialize_f32(self, v: f32) -> Result<Self::Ok, Self::Error>
fn serialize_f32(self, v: f32) -> Result<Self::Ok, Self::Error>
Serialize an f32 value. Read more
sourcefn serialize_f64(self, v: f64) -> Result<Self::Ok, Self::Error>
fn serialize_f64(self, v: f64) -> Result<Self::Ok, Self::Error>
Serialize an f64 value. Read more
sourcefn serialize_char(self, v: char) -> Result<Self::Ok, Self::Error>
fn serialize_char(self, v: char) -> Result<Self::Ok, Self::Error>
Serialize a character. Read more
sourcefn serialize_bytes(self, v: &[u8]) -> Result<Self::Ok, Self::Error>
fn serialize_bytes(self, v: &[u8]) -> Result<Self::Ok, Self::Error>
Serialize a chunk of raw byte data. Read more
sourcefn serialize_some<T: ?Sized>(self, value: &T) -> Result<Self::Ok, Self::Error> where
T: Serialize,
fn serialize_some<T: ?Sized>(self, value: &T) -> Result<Self::Ok, Self::Error> where
T: Serialize,
sourcefn serialize_unit_struct(
self,
_name: &'static str
) -> Result<Self::Ok, Self::Error>
fn serialize_unit_struct(
self,
_name: &'static str
) -> Result<Self::Ok, Self::Error>
Serialize a unit struct like struct Unit or PhantomData<T>. Read more
sourcefn serialize_unit_variant(
self,
_name: &'static str,
_variant_index: u32,
_variant: &'static str
) -> Result<Self::Ok, Self::Error>
fn serialize_unit_variant(
self,
_name: &'static str,
_variant_index: u32,
_variant: &'static str
) -> Result<Self::Ok, Self::Error>
Serialize a unit variant like E::A in enum E { A, B }. Read more
sourcefn serialize_newtype_struct<T: ?Sized>(
self,
_name: &'static str,
value: &T
) -> Result<Self::Ok, Self::Error> where
T: Serialize,
fn serialize_newtype_struct<T: ?Sized>(
self,
_name: &'static str,
value: &T
) -> Result<Self::Ok, Self::Error> where
T: Serialize,
Serialize a newtype struct like struct Millimeters(u8). Read more
sourcefn serialize_newtype_variant<T: ?Sized>(
self,
_name: &'static str,
_variant_index: u32,
_variant: &'static str,
value: &T
) -> Result<Self::Ok, Self::Error> where
T: Serialize,
fn serialize_newtype_variant<T: ?Sized>(
self,
_name: &'static str,
_variant_index: u32,
_variant: &'static str,
value: &T
) -> Result<Self::Ok, Self::Error> where
T: Serialize,
Serialize a newtype variant like E::N in enum E { N(u8) }. Read more
sourcefn serialize_seq(
self,
_len: Option<usize>
) -> Result<Self::SerializeSeq, Self::Error>
fn serialize_seq(
self,
_len: Option<usize>
) -> Result<Self::SerializeSeq, Self::Error>
Begin to serialize a variably sized sequence. This call must be
followed by zero or more calls to serialize_element, then a call to
end. Read more
sourcefn serialize_tuple(
self,
_len: usize
) -> Result<Self::SerializeTuple, Self::Error>
fn serialize_tuple(
self,
_len: usize
) -> Result<Self::SerializeTuple, Self::Error>
Begin to serialize a statically sized sequence whose length will be
known at deserialization time without looking at the serialized data.
This call must be followed by zero or more calls to serialize_element,
then a call to end. Read more
sourcefn serialize_tuple_struct(
self,
_name: &'static str,
_len: usize
) -> Result<Self::SerializeTupleStruct, Self::Error>
fn serialize_tuple_struct(
self,
_name: &'static str,
_len: usize
) -> Result<Self::SerializeTupleStruct, Self::Error>
Begin to serialize a tuple struct like struct Rgb(u8, u8, u8). This
call must be followed by zero or more calls to serialize_field, then a
call to end. Read more
sourcefn serialize_tuple_variant(
self,
_name: &'static str,
_variant_index: u32,
_variant: &'static str,
_len: usize
) -> Result<Self::SerializeTupleVariant, Self::Error>
fn serialize_tuple_variant(
self,
_name: &'static str,
_variant_index: u32,
_variant: &'static str,
_len: usize
) -> Result<Self::SerializeTupleVariant, Self::Error>
Begin to serialize a tuple variant like E::T in enum E { T(u8, u8) }. This call must be followed by zero or more calls to
serialize_field, then a call to end. Read more
sourcefn serialize_map(
self,
_len: Option<usize>
) -> Result<Self::SerializeMap, Self::Error>
fn serialize_map(
self,
_len: Option<usize>
) -> Result<Self::SerializeMap, Self::Error>
Begin to serialize a map. This call must be followed by zero or more
calls to serialize_key and serialize_value, then a call to end. Read more
sourcefn serialize_struct(
self,
_name: &'static str,
_len: usize
) -> Result<Self::SerializeStruct, Self::Error>
fn serialize_struct(
self,
_name: &'static str,
_len: usize
) -> Result<Self::SerializeStruct, Self::Error>
Begin to serialize a struct like struct Rgb { r: u8, g: u8, b: u8 }.
This call must be followed by zero or more calls to serialize_field,
then a call to end. Read more
sourcefn serialize_struct_variant(
self,
_name: &'static str,
_variant_index: u32,
_variant: &'static str,
_len: usize
) -> Result<Self::SerializeStructVariant, Self::Error>
fn serialize_struct_variant(
self,
_name: &'static str,
_variant_index: u32,
_variant: &'static str,
_len: usize
) -> Result<Self::SerializeStructVariant, Self::Error>
Begin to serialize a struct variant like E::S in enum E { S { r: u8, g: u8, b: u8 } }. This call must be followed by zero or more calls to
serialize_field, then a call to end. Read more
sourcefn collect_seq<I>(self, iter: I) -> Result<Self::Ok, Self::Error> where
I: IntoIterator,
<I as IntoIterator>::Item: Serialize,
fn collect_seq<I>(self, iter: I) -> Result<Self::Ok, Self::Error> where
I: IntoIterator,
<I as IntoIterator>::Item: Serialize,
Collect an iterator as a sequence. Read more
sourcefn collect_map<K, V, I>(self, iter: I) -> Result<Self::Ok, Self::Error> where
K: Serialize,
V: Serialize,
I: IntoIterator<Item = (K, V)>,
fn collect_map<K, V, I>(self, iter: I) -> Result<Self::Ok, Self::Error> where
K: Serialize,
V: Serialize,
I: IntoIterator<Item = (K, V)>,
Collect an iterator as a map. Read more
sourcefn collect_str<T>(self, value: &T) -> Result<Self::Ok, Self::Error> where
T: Display + ?Sized,
fn collect_str<T>(self, value: &T) -> Result<Self::Ok, Self::Error> where
T: Display + ?Sized,
Serialize a string produced by an implementation of Display. Read more
sourcefn is_human_readable(&self) -> bool
fn is_human_readable(&self) -> bool
Determine whether Serialize implementations should serialize in
human-readable form. Read more